WeightUnit class
An enum for numerous WeightConverters.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
parse(
String id) → WeightConverter? -
Returns the WeightConverter for this
idor null if there is no WeightConverter associated with this id.
Constants
- atomicMassUnit → const WeightConverter
- attogram → const WeightConverter
- carat → const WeightConverter
- centigram → const WeightConverter
-
common
→ const List<
WeightConverter> - dalton → const WeightConverter
- decigram → const WeightConverter
- dekagram → const WeightConverter
- deuteronMass → const WeightConverter
- earthMass → const WeightConverter
- electronMass → const WeightConverter
- exagram → const WeightConverter
- femtogram → const WeightConverter
- gigagram → const WeightConverter
- grain → const WeightConverter
- gram → const WeightConverter
- hectogram → const WeightConverter
- hundredWeightUK → const WeightConverter
- hundredWeightUS → const WeightConverter
- kilogram → const WeightConverter
- kiloton → const WeightConverter
- megagram → const WeightConverter
- microgram → const WeightConverter
- milligram → const WeightConverter
- muonMass → const WeightConverter
- nanogram → const WeightConverter
- neutronMass → const WeightConverter
- ounce → const WeightConverter
- pennyweight → const WeightConverter
- petagram → const WeightConverter
- picogram → const WeightConverter
- plankMass → const WeightConverter
- pound → const WeightConverter
- poundal → const WeightConverter
- protonMass → const WeightConverter
- quarterUK → const WeightConverter
- quarterUS → const WeightConverter
- quintal → const WeightConverter
- stoneUK → const WeightConverter
- stoneUS → const WeightConverter
- sunMass → const WeightConverter
- teragram → const WeightConverter
- ton → const WeightConverter
- tonUK → const WeightConverter
- tonUS → const WeightConverter
-
units
→ const List<
WeightConverter>